# Generated by roxygen2: do not edit by hand

S3method(plot,visstat)
S3method(print,games.howell)
S3method(print,visstat)
S3method(summary,visstat)
export(bp.test)
export(counts_to_cases)
export(games.howell)
export(gh_letters)
export(levene.test)
export(openGraphCairo)
export(saveGraphVisstat)
export(vis_anova)
export(vis_anova_assumptions)
export(vis_group_normality)
export(vis_lm_assumptions)
export(vis_numeric)
export(visstat)
export(visstat_core)
import(Cairo)
import(grDevices)
import(graphics)
import(grid)
import(multcompView)
import(stats)
import(utils)
import(vcd)
importFrom(nortest,ad.test)
