% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visstat_methods.R
\name{print.visstat}
\alias{print.visstat}
\title{Print method for visstat objects}
\usage{
\method{print}{visstat}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"visstat"}, returned by
\code{visstat()}.}

\item{...}{Currently unused. Included for S3 method compatibility.}
}
\value{
The object \code{x}, invisibly.
}
\description{
Displays a brief summary of the statistical test results and, if
available, assumption tests and post hoc comparisons.
}
\details{
Quick overview of the statistical analysis results.
}
\examples{
anova <- visstat(npk$block, npk$yield)
print(anova)

}
\seealso{
\code{\link{summary.visstat}},
  \code{\link{plot.visstat}}, \code{\link{visstat}}
}
