% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visstat_methods.R
\name{summary.visstat}
\alias{summary.visstat}
\title{Summary method for visstat objects}
\usage{
\method{summary}{visstat}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"visstat"}, returned by
\code{visstat()}.}

\item{...}{Currently unused. Included for S3 method compatibility.}
}
\value{
The object \code{object}, invisibly.
}
\description{
Displays the full statistical test results and, if available,
assumption tests and post hoc comparisons.
}
\details{
This method provides a full textual report of the statistical
test results returned by \code{visstat()}, and prints the contents of
\code{posthoc_summary} if present.
}
\examples{
anova <- visstat(npk$block, npk$yield)
summary(anova)

}
\seealso{
\code{\link{print.visstat}}, \code{\link{visstat}}
}
